=======
Authors
=======

Original Authors
================

* Sam Brightman (`@sambrightman <https://github.com/sambrightman>`_)

Awesome Contributors
====================

You can also see a `full list of all the contributions`_.

.. _`full list of all the contributions`: https://github.com/sambrightman/asciidag/contributors
